Denoise Restoration
--------------------


Classic
~~~~~~~~~~~~~~~~~~~~~

Procedural API:
    .. currentmodule:: aydin

    .. autofunction:: classic_denoise



Object-Oriented API:
    .. currentmodule:: aydin.restoration.denoise.classic

    .. autoclass:: Classic
       :members:
       :inherited-members:


Noise2SelfFGR
~~~~~~~~~~~~~~~~~~~~~

Procedural API:
    .. currentmodule:: aydin

    .. autofunction:: noise2self_fgr



Object-Oriented API:
    .. currentmodule:: aydin.restoration.denoise.noise2selffgr

    .. autoclass:: Noise2SelfFGR
       :members:
       :inherited-members:



Noise2SelfCNN
~~~~~~~~~~~~~~~~~~~~~

Procedural API:
    .. currentmodule:: aydin

    .. autofunction:: noise2self_cnn



Object-Oriented API:
    .. currentmodule:: aydin.restoration.denoise.noise2selfcnn

    .. autoclass:: Noise2SelfCNN
       :members:
       :inherited-members: